@@ -14,21 +14,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
 import requests
+from unittest import mock
 
-import six
-import ujson as json
+import simplejson as json
 
 from monasca_notification import notification as m_notification
 from monasca_notification.plugins import webhook_notifier
+import queue
 from tests import base
 
-if six.PY2:
-    import Queue as queue
-else:
-    import queue
-
 
 def alarm(metrics):
     return {"tenantId": "0",
